Function Based Tutorials
========================

.. currentmodule:: H2MM_C

This section is recommended for beginners with Python, and especially those not familiar with object oriented programming languages (e.g. those coming from matlab).

.. seealso::

    :doc:`Object Oriented Tutorials <OOTutorial>` for a cleaner, object oriented set of tutorials.
    These are all equivalent tutorials, just in a different style of programming.


.. toctree::
    :caption: Tutorials
    :maxdepth: 2

    FOptimizationTutorial
    FBoundingTutorial

